WebSocket
=========

Real-time streaming via the eToro WebSocket API.

WsClient
--------

.. autoclass:: etoropy.WsClient
   :members:
   :show-inheritance:

WsClientOptions
---------------

.. autoclass:: etoropy.WsClientOptions
   :members:

Message Parser
--------------

.. automodule:: etoropy.ws.message_parser
   :members:
   :show-inheritance:

Subscription Tracker
--------------------

.. autoclass:: etoropy.ws.WsSubscriptionTracker
   :members:
   :show-inheritance:
